@@ -131,7 +131,7 @@ class DRKApp:
             "origin": api_url
         }
 
-        response = requests.get(f"{api_url}{final_api}/{id}/", headers=headers)
+        response = requests.get(f"{api_url}{final_api}{id}/", headers=headers)
 
         if response.status_code == 200 or response.status_code == 201:
             data = response.json()
